==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/iot/kotlin/inputs/TopicRuleCloudwatchMetricArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.iot.kotlin.inputs

import com.pulumi.aws.iot.inputs.TopicRuleCloudwatchMetricArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property metricName The CloudWatch metric name.
 * @property metricNamespace The CloudWatch metric namespace name.
 * @property metricTimestamp An optional Unix timestamp (http://docs.aws.amazon.com/AmazonCloudWatch/latest/DeveloperGuide/cloudwatch_concepts.html#about_timestamp).
 * @property metricUnit The metric unit (supported units can be found here: http://docs.aws.amazon.com/AmazonCloudWatch/latest/DeveloperGuide/cloudwatch_concepts.html#Unit)
 * @property metricValue The CloudWatch metric value.
 * @property roleArn The IAM role ARN that allows access to the CloudWatch metric.
 */
public data class TopicRuleCloudwatchMetricArgs(
    public val metricName: Output<String>,
    public val metricNamespace: Output<String>,
    public val metricTimestamp: Output<String>? = null,
    public val metricUnit: Output<String>,
    public val metricValue: Output<String>,
    public val roleArn: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.iot.inputs.TopicRuleCloudwatchMetricArgs> {
    override fun toJava(): com.pulumi.aws.iot.inputs.TopicRuleCloudwatchMetricArgs =
        com.pulumi.aws.iot.inputs.TopicRuleCloudwatchMetricArgs.builder()
            .metricName(metricName.applyValue({ args0 -> args0 }))
            .metricNamespace(metricNamespace.applyValue({ args0 -> args0 }))
            .metricTimestamp(metricTimestamp?.applyValue({ args0 -> args0 }))
            .metricUnit(metricUnit.applyValue({ args0 -> args0 }))
            .metricValue(metricValue.applyValue({ args0 -> args0 }))
            .roleArn(roleArn.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [TopicRuleCloudwatchMetricArgs].
 */
@PulumiTagMarker
public class TopicRuleCloudwatchMetricArgsBuilder internal constructor() {
    private var metricName: Output<String>? = null

    private var metricNamespace: Output<String>? = null

    private var metricTimestamp: Output<String>? = null

    private var metricUnit: Output<String>? = null

    private var metricValue: Output<String>? = null

    private var roleArn: Output<String>? = null

    /**
     * @param value The CloudWatch metric name.
     */
    @JvmName("udeiqoapttangske")
    public suspend fun metricName(`value`: Output<String>) {
        this.metricName = value
    }

    /**
     * @param value The CloudWatch metric namespace name.
     */
    @JvmName("locrpquwuihfipij")
    public suspend fun metricNamespace(`value`: Output<String>) {
        this.metricNamespace = value
    }

    /**
     * @param value An optional Unix timestamp (http://docs.aws.amazon.com/AmazonCloudWatch/latest/DeveloperGuide/cloudwatch_concepts.html#about_timestamp).
     */
    @JvmName("qeohxvpdnbeykfhs")
    public suspend fun metricTimestamp(`value`: Output<String>) {
        this.metricTimestamp = value
    }

    /**
     * @param value The metric unit (supported units can be found here: http://docs.aws.amazon.com/AmazonCloudWatch/latest/DeveloperGuide/cloudwatch_concepts.html#Unit)
     */
    @JvmName("tvryiqucdjfasfoe")
    public suspend fun metricUnit(`value`: Output<String>) {
        this.metricUnit = value
    }

    /**
     * @param value The CloudWatch metric value.
     */
    @JvmName("gctpstutvnulxjux")
    public suspend fun metricValue(`value`: Output<String>) {
        this.metricValue = value
    }

    /**
     * @param value The IAM role ARN that allows access to the CloudWatch metric.
     */
    @JvmName("xqmclploinuqsrad")
    public suspend fun roleArn(`value`: Output<String>) {
        this.roleArn = value
    }

    /**
     * @param value The CloudWatch metric name.
     */
    @JvmName("hdgnyofwxlqymodr")
    public suspend fun metricName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.metricName = mapped
    }

    /**
     * @param value The CloudWatch metric namespace name.
     */
    @JvmName("wlsbxocjkobormpt")
    public suspend fun metricNamespace(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.metricNamespace = mapped
    }

    /**
     * @param value An optional Unix timestamp (http://docs.aws.amazon.com/AmazonCloudWatch/latest/DeveloperGuide/cloudwatch_concepts.html#about_timestamp).
     */
    @JvmName("usgwibbdhdfxntwn")
    public suspend fun metricTimestamp(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.metricTimestamp = mapped
    }

    /**
     * @param value The metric unit (supported units can be found here: http://docs.aws.amazon.com/AmazonCloudWatch/latest/DeveloperGuide/cloudwatch_concepts.html#Unit)
     */
    @JvmName("comgbfhypkuekjhy")
    public suspend fun metricUnit(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.metricUnit = mapped
    }

    /**
     * @param value The CloudWatch metric value.
     */
    @JvmName("xbpiwrulrlmrnubo")
    public suspend fun metricValue(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.metricValue = mapped
    }

    /**
     * @param value The IAM role ARN that allows access to the CloudWatch metric.
     */
    @JvmName("gmjqfuvamxljlcab")
    public suspend fun roleArn(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.roleArn = mapped
    }

    internal fun build(): TopicRuleCloudwatchMetricArgs = TopicRuleCloudwatchMetricArgs(
        metricName = metricName ?: throw PulumiNullFieldException("metricName"),
        metricNamespace = metricNamespace ?: throw PulumiNullFieldException("metricNamespace"),
        metricTimestamp = metricTimestamp,
        metricUnit = metricUnit ?: throw PulumiNullFieldException("metricUnit"),
        metricValue = metricValue ?: throw PulumiNullFieldException("metricValue"),
        roleArn = roleArn ?: throw PulumiNullFieldException("roleArn"),
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/iot/kotlin/inputs/TopicRuleCloudwatchMetricArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.iot.kotlin.inputs

import com.pulumi.aws.iot.inputs.TopicRuleCloudwatchMetricArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property metricName The CloudWatch metric name.
 * @property metricNamespace The CloudWatch metric namespace name.
 * @property metricTimestamp An optional Unix timestamp (http://docs.aws.amazon.com/AmazonCloudWatch/latest/DeveloperGuide/cloudwatch_concepts.html#about_timestamp).
 * @property metricUnit The metric unit (supported units can be found here: http://docs.aws.amazon.com/AmazonCloudWatch/latest/DeveloperGuide/cloudwatch_concepts.html#Unit)
 * @property metricValue The CloudWatch metric value.
 * @property roleArn The IAM role ARN that allows access to the CloudWatch metric.
 */
public data class TopicRuleCloudwatchMetricArgs(
    public val metricName: Output<String>,
    public val metricNamespace: Output<String>,
    public val metricTimestamp: Output<String>? = null,
    public val metricUnit: Output<String>,
    public val metricValue: Output<String>,
    public val roleArn: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.iot.inputs.TopicRuleCloudwatchMetricArgs> {
    override fun toJava(): com.pulumi.aws.iot.inputs.TopicRuleCloudwatchMetricArgs =
        com.pulumi.aws.iot.inputs.TopicRuleCloudwatchMetricArgs.builder()
            .metricName(metricName.applyValue({ args0 -> args0 }))
            .metricNamespace(metricNamespace.applyValue({ args0 -> args0 }))
            .metricTimestamp(metricTimestamp?.applyValue({ args0 -> args0 }))
            .metricUnit(metricUnit.applyValue({ args0 -> args0 }))
            .metricValue(metricValue.applyValue({ args0 -> args0 }))
            .roleArn(roleArn.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [TopicRuleCloudwatchMetricArgs].
 */
@PulumiTagMarker
public class TopicRuleCloudwatchMetricArgsBuilder internal constructor() {
    private var metricName: Output<String>? = null

    private var metricNamespace: Output<String>? = null

    private var metricTimestamp: Output<String>? = null

    private var metricUnit: Output<String>? = null

    private var metricValue: Output<String>? = null

    private var roleArn: Output<String>? = null

    /**
     * @param value The CloudWatch metric name.
     */
    @JvmName("strvacbrqxccbnkv")
    public suspend fun metricName(`value`: Output<String>) {
        this.metricName = value
    }

    /**
     * @param value The CloudWatch metric namespace name.
     */
    @JvmName("vymjwlqqitwnfqyo")
    public suspend fun metricNamespace(`value`: Output<String>) {
        this.metricNamespace = value
    }

    /**
     * @param value An optional Unix timestamp (http://docs.aws.amazon.com/AmazonCloudWatch/latest/DeveloperGuide/cloudwatch_concepts.html#about_timestamp).
     */
    @JvmName("agxnqwlaowutmrng")
    public suspend fun metricTimestamp(`value`: Output<String>) {
        this.metricTimestamp = value
    }

    /**
     * @param value The metric unit (supported units can be found here: http://docs.aws.amazon.com/AmazonCloudWatch/latest/DeveloperGuide/cloudwatch_concepts.html#Unit)
     */
    @JvmName("ohakbcfytnsdqfdl")
    public suspend fun metricUnit(`value`: Output<String>) {
        this.metricUnit = value
    }

    /**
     * @param value The CloudWatch metric value.
     */
    @JvmName("lcspbnmkumfxqhcn")
    public suspend fun metricValue(`value`: Output<String>) {
        this.metricValue = value
    }

    /**
     * @param value The IAM role ARN that allows access to the CloudWatch metric.
     */
    @JvmName("foesjusgeikbsqkr")
    public suspend fun roleArn(`value`: Output<String>) {
        this.roleArn = value
    }

    /**
     * @param value The CloudWatch metric name.
     */
    @JvmName("fdpxprxxxtjuterf")
    public suspend fun metricName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.metricName = mapped
    }

    /**
     * @param value The CloudWatch metric namespace name.
     */
    @JvmName("pbhishqqcausqngd")
    public suspend fun metricNamespace(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.metricNamespace = mapped
    }

    /**
     * @param value An optional Unix timestamp (http://docs.aws.amazon.com/AmazonCloudWatch/latest/DeveloperGuide/cloudwatch_concepts.html#about_timestamp).
     */
    @JvmName("lmxqrsanomwwnwfn")
    public suspend fun metricTimestamp(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.metricTimestamp = mapped
    }

    /**
     * @param value The metric unit (supported units can be found here: http://docs.aws.amazon.com/AmazonCloudWatch/latest/DeveloperGuide/cloudwatch_concepts.html#Unit)
     */
    @JvmName("yuhxqvnxqlsjlaxk")
    public suspend fun metricUnit(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.metricUnit = mapped
    }

    /**
     * @param value The CloudWatch metric value.
     */
    @JvmName("hhremfcdyijgyxxe")
    public suspend fun metricValue(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.metricValue = mapped
    }

    /**
     * @param value The IAM role ARN that allows access to the CloudWatch metric.
     */
    @JvmName("kxxnwjdwffnhndll")
    public suspend fun roleArn(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.roleArn = mapped
    }

    internal fun build(): TopicRuleCloudwatchMetricArgs = TopicRuleCloudwatchMetricArgs(
        metricName = metricName ?: throw PulumiNullFieldException("metricName"),
        metricNamespace = metricNamespace ?: throw PulumiNullFieldException("metricNamespace"),
        metricTimestamp = metricTimestamp,
        metricUnit = metricUnit ?: throw PulumiNullFieldException("metricUnit"),
        metricValue = metricValue ?: throw PulumiNullFieldException("metricValue"),
        roleArn = roleArn ?: throw PulumiNullFieldException("roleArn"),
    )
}
